@@ -487,19 +487,22 @@ def diff2(arg1, arg2, show_graph=0, p=0):
                      f'{arg2} - {arg1}': dir_arg2 - dir_arg1,
                      f'{arg1} & {arg2}': dir_arg1 & dir_arg2}
 
+    sorted_returned_tuple = sorted(returned_dict.items(), key=lambda x: len(x[1]))
+    sorted_returned_list = [{i: j} for i, j in sorted_returned_tuple if j]
+
     if show_graph:
         import upsetplot
         graph_dict = {f'{arg1}': dir_arg1,
                       f'{arg2}': dir_arg2}
 
         upset_data_sub = upsetplot.from_contents({k: v for k, v in graph_dict.items()})
-        upsetplot.plot(upset_data_sub, show_counts=True)
+        upsetplot.plot(upset_data_sub, show_counts=True, sort_by='cardinality')
 
     if p:
         from pprint import pprint
-        pprint(returned_dict, compact=True, width=120)
+        pprint(sorted_returned_list, compact=True, width=120)
     else:
-        return returned_dict
+        return sorted_returned_list
 
 
 def diff3(arg1, arg2, arg3, show_graph=0, p=0):
@@ -511,6 +514,9 @@ def diff3(arg1, arg2, arg3, show_graph=0, p=0):
                      f'{arg1} & {arg3} - {arg2}': set(dir(arg1)) & set(dir(arg3)) - set(dir(arg2)),
                      f'{arg1} & {arg2} & {arg3}': set(dir(arg1)) & set(dir(arg2)) & set(dir(arg3))}
 
+    sorted_returned_tuple = sorted(returned_dict.items(), key=lambda x: len(x[1]))
+    sorted_returned_list = [{i: j} for i, j in sorted_returned_tuple if j]
+
     if show_graph:
         import upsetplot
         graph_dict = {f'{arg1}': set(dir(arg1)),
@@ -518,10 +524,10 @@ def diff3(arg1, arg2, arg3, show_graph=0, p=0):
                       f'{arg3}': set(dir(arg3))}
 
         upset_data_sub = upsetplot.from_contents({k: v for k, v in graph_dict.items()})
-        upsetplot.plot(upset_data_sub, show_counts=True)
+        upsetplot.plot(upset_data_sub, show_counts=True, sort_by='cardinality')
 
     if p:
         from pprint import pprint
-        pprint(returned_dict, compact=True, width=120)
+        pprint(sorted_returned_list, compact=True, width=120)
     else:
-        return returned_dict
+        return sorted_returned_list
